# Generated by Django 5.0.8 on 2024-09-12 13:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_config_backup', '0014_backup_config_status'),
    ]

    operations = [
        migrations.AddField(
            model_name='backup',
            name='comments',
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name='backup',
            name='description',
            field=models.CharField(blank=True, max_length=200),
        ),
    ]
