# Generated by Django 5.0.8 on 2024-09-30 21:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_config_backup', '0015_backup_comments_backup_description'),
    ]

    operations = [
        migrations.AddField(
            model_name='backupjob',
            name='pid',
            field=models.BigIntegerField(blank=True, null=True),
        ),
    ]
