# Generated by Django 5.0.9 on 2024-11-18 23:14

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dcim', '0191_module_bay_rebuild'),
        ('netbox_config_backup', '0018_move_to_nbmodel'),
    ]

    operations = [
        migrations.AlterField(
            model_name='backup',
            name='device',
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name='backups',
                to='dcim.device',
            ),
        ),
    ]
